import { CollectionConfig } from "payload";

export const Repositories: CollectionConfig = {
  slug: 'repositories', admin: {
    useAsTitle: 'name'
  },
  fields: [
    {
      name: 'name',
      type: 'text',
      required: true,
      unique: true
    },
    {
      name: 'abbreviation',
      type: 'text',
      required: true,
      unique: true,
      admin: {
        description: 'This is used to help identify which copies belong to this repo.'
      }
    },
    {
      name: 'owner',
      type: 'relationship',
      relationTo: 'users',
      hasMany: true,
      required: true,
    },
    {
      name: 'dateOpenToPublic',
      type: 'date'
    },
    {
      name: 'holdRequests',
      type: 'join',
      collection: 'holdRequests',
      on: 'repository',
      defaultSort: 'dateRequested',
      where: {
        or: [
          {
            isCheckedOut: {
              equals: false
            }
          },
          {
            isCheckedOut: {
              equals: null
            }
          }
        ]
      }
    },
  ]
}
